@@ -13,6 +13,9 @@ class CheckPayment(QuickbooksBaseObject):
         self.PrintStatus = ""
         self.BankAccountRef = None
 
+    def __unicode__(self):
+        return self.PrintStatus
+
 
 class BillPaymentLine(QuickbooksBaseObject):
     list_dict = {
@@ -27,7 +30,7 @@ class BillPaymentLine(QuickbooksBaseObject):
         self.LinkedTxn = []
 
     def __unicode__(self):
-        return self.Amount
+        return str(self.Amount)
 
 
 class BillPayment(QuickbooksManagedObject):
@@ -66,3 +69,5 @@ class BillPayment(QuickbooksManagedObject):
 
         self.Line = []
 
+    def __unicode__(self):
+        return str(self.TotalAmt)
\ No newline at end of file
