@@ -16,6 +16,9 @@ class SalesItemLineDetail(QuickbooksBaseObject):
         self.ItemRef = None
         self.TaxCodeRef = None
 
+    def __unicode__(self):
+        return str(self.UnitPrice)
+
 
 class CreditMemoLine(QuickbooksBaseObject):
     class_dict = {
@@ -31,6 +34,9 @@ class CreditMemoLine(QuickbooksBaseObject):
 
         self.SalesItemLineDetail = None
 
+    def __unicode__(self):
+        return "[{0}] {1} {2}".format(self.LineNum, self.Description, self.Amount)
+
 
 class CreditMemo(QuickbooksManagedObject):
     """
@@ -63,8 +69,8 @@ class CreditMemo(QuickbooksManagedObject):
         self.PrivateNote = ""
         self.TotalAmt = 0
         self.ApplyTaxAfterDiscount = ""
-        self.PrintStatus = ""
-        self.EmailStatus = ""
+        self.PrintStatus = "NotSet"
+        self.EmailStatus = "NotSet"
         self.Balance = 0
 
         self.BillAddr = None
@@ -77,3 +83,5 @@ class CreditMemo(QuickbooksManagedObject):
         self.CustomField = []
         self.Line = []
 
+    def __unicode__(self):
+        return str(self.TotalAmt)
