@@ -12,6 +12,9 @@ class SalesItemLineDetail(QuickbooksBaseObject):
         self.UnitPrice = 0
         self.Qty = 0
 
+    def __unicode__(self):
+        return str(self.UnitPrice)
+
 
 class EstimateLine(QuickbooksBaseObject):
     class_dict = {
@@ -26,6 +29,8 @@ class EstimateLine(QuickbooksBaseObject):
         self.DetailType = ""
         self.SalesItemLineDetail = None
 
+    def __unicode__(self):
+        return str(self.Amount)
 
 
 class Estimate(QuickbooksManagedObject):
@@ -56,11 +61,14 @@ class Estimate(QuickbooksManagedObject):
         self.TxnStatus = ""
         self.TotalAmt = 0
         self.ApplyTaxAfterDiscount = 0
-        self.PrintStatus = ""
-        self.EmailStatus = ""
+        self.PrintStatus = "NotSet"
+        self.EmailStatus = "NotSet"
         self.BillAddr = None
         self.ShipAddr = None
         self.CustomerRef = None
         self.TxnTaxDetail = None
         self.CustomerMemo = None
         self.CustomField = []
+
+    def __unicode__(self):
+        return str(self.TotalAmt)
