@@ -2,7 +2,6 @@ from base import QuickbooksBaseObject, Ref, CustomField, QuickbooksManagedObject
 from tax import TxnTaxDetail
 
 
-
 class SalesItemLineDetail(QuickbooksBaseObject):
     class_dict = {
         "ItemRef": Ref,
@@ -28,6 +27,9 @@ class RefundReceiptLine(QuickbooksBaseObject):
 
         self.SalesItemLineDetail = None
 
+    def __unicode__(self):
+        return str(self.Amount)
+
 
 class RefundReceipt(QuickbooksManagedObject):
     """
@@ -60,3 +62,6 @@ class RefundReceipt(QuickbooksManagedObject):
         self.DepositToAccountRef = None
         self.CustomField = []
         self.Line = []
+
+    def __unicode__(self):
+        return str(self.TotalAmt)
