@@ -12,6 +12,9 @@ class TaxLineDetail(QuickbooksBaseObject):
         self.TaxPercent = 0
         self.NetAmountTaxable = 0
 
+    def __unicode__(self):
+        return str(self.TaxPercent)
+
 
 class TaxLine(QuickbooksBaseObject):
     class_dict = {
@@ -23,6 +26,9 @@ class TaxLine(QuickbooksBaseObject):
         self.Amount = 0
         self.DetailType = ""
 
+    def __unicode__(self):
+        return str(self.Amount)
+
 
 class TxnTaxDetail(QuickbooksManagedObject):
     class_dict = {
@@ -38,3 +44,6 @@ class TxnTaxDetail(QuickbooksManagedObject):
         self.TotalTax = 0
         self.TxnTaxCodeRef = None
         self.TaxLine = []
+
+    def __unicode__(self):
+        return str(self.TotalTax)
